@@ -43,6 +43,10 @@ if (!isGeneric("demom")) {
 }
 
 
+if (!isGeneric("getAIC")) {
+  setGeneric("getAIC", function(object) standardGeneric("getAIC"))
+}
+
 if (!isGeneric("getBIC")) {
   setGeneric("getBIC", function(object) standardGeneric("getBIC"))
 }
@@ -51,6 +55,10 @@ if (!isGeneric("getEBIC")) {
   setGeneric("getEBIC", function(object) standardGeneric("getEBIC"))
 }
 
+if (!isGeneric("getIC")) {
+  setGeneric("getIC", function(object) standardGeneric("getIC"))
+}
+
 
 if (!isGeneric("marginalIW")) {
   setGeneric("marginalNIW", function(x, xbar, samplecov, n, z, g,  mu0=rep(0,ncol(x)), nu0=ncol(x)+4, S0,logscale=TRUE) standardGeneric("marginalNIW"))
